*********
Changelog
*********
Develop
=======


Major Features and Improvements
-------------------------------

Breaking changes
------------------

Depreceations
-------------


Bug fixes and small changes
---------------------------

Experimental
------------

Requirement changes
-------------------

Thanks
------

0.2.0
=======

Added relativistic Breit-Wigner PDF

Many thanks to Simon Thor <simon11.thor@hotmail.se> for contributing the Relativistic BW

0.1.0
=======

Upgrade to zfit >= 0.6


0.0.3 (14.05.2020)
==================


Major Features and Improvements
-------------------------------
- added ARGUS pdf


Bug fixes and small changes
---------------------------
- fix KDE with numerical integration


Requirement changes
-------------------
- zfit >= 5.2

Thanks
------
- Colm Murphy <colm.murphy@ipmu.jp> for help in contributing the ARGUS PDF
